@@ -122,7 +122,7 @@ class modpath_from_file_tc(ModutilsTestCase):
         with warnings.catch_warnings(record=True) as warns:
             self.assertEqual(modutils.modpath_from_file(modutils.__file__),
                              ['logilab', 'common', 'modutils'])
-            self.assertIn('you should avoid using modpath_from_file()',
+            self.assertIn('[logilab.common] you should avoid using modpath_from_file()',
                           [str(w.message) for w in warns])
 
     def test_knownValues_modpath_from_file_2(self):
