@@ -181,7 +181,7 @@ class RegistryStoreTC(TestCase):
             with warnings.catch_warnings(record=True) as warns:
                 store.register_objects([self.datapath('regobjects.py'),
                                         self.datapath('regobjects2.py')])
-                self.assertIn('use register_modnames() instead',
+                self.assertIn('[logilab.common] use register_modnames() instead',
                               [str(w.message) for w in warns])
         self.assertEqual(['zereg'], list(store.keys()))
         self.assertEqual(set(('appobject1', 'appobject2', 'appobject3')),
